import com.imsl.stat.*;
import com.imsl.math.*;
import com.imsl.datamining.neural.*;

public class ScaleFilterEx1 {
    public static void main(String args[]) throws Exception {
        ScaleFilter[] scaleFilter = new ScaleFilter[3];
        scaleFilter[0] = new ScaleFilter(ScaleFilter.NO_SCALING);
        scaleFilter[1] = 
            new ScaleFilter(ScaleFilter.BOUNDED_Z_SCORE_SCALING_MEAN_STDEV);
        scaleFilter[1].setBounds(-6.0, 6.0, -3.0, 3.0);
        scaleFilter[2] = 
            new ScaleFilter(ScaleFilter.BOUNDED_Z_SCORE_SCALING_MEDIAN_MAD);
        scaleFilter[2].setBounds(-3.0, 3.0, -3.0, 3.0);
        int nObs = 5;
        double[] y0, y1, y2;
        double[] x0 = {1.2, 0.0, -1.4, 1.5, 3.2};
        double[] x1 = {3.5, 2.4, 4.4, 5.6, 1.1};
        double[] x2 = {3.1, 1.5, -1.5, 2.4, 4.2};

        // Perform forward filtering
        y0 = scaleFilter[0].encode(x0);
        y1 = scaleFilter[1].encode(x1);
        y2 = scaleFilter[2].encode(x2);
        // Display x0
        System.out.print("X0 = {");
        for (int i=0; i<4; i++) System.out.print(x0[i]+", ");
        System.out.println(x0[4]+"}");
        // Display summary statistics for X1
        System.out.print("\nX1 = {");
        for (int i=0; i<4; i++) System.out.print(x1[i]+", ");
        System.out.println(x1[4]+"}");
        System.out.println("X1 Mean:       "+scaleFilter[1].getCenter());
        System.out.println("X1 Std. Dev.:  "+scaleFilter[1].getSpread());
        // Display summary statistics for X2
        System.out.print("\nX2 = {");
        for (int i=0; i<4; i++) System.out.print(x2[i]+", ");
        System.out.println(x2[4]+"}");
        System.out.println("X2 Median:     "+scaleFilter[2].getCenter());
        System.out.println("X2 MAD/0.6745: "+scaleFilter[2].getSpread());
        System.out.println("");
        PrintMatrix pm = new PrintMatrix();        
        pm.setTitle("Filtered X0 Using Method=0 (no scaling)");
        pm.print(y0);
        pm.setTitle("Filtered X1 Using Bounded Z-score Scaling\n"+
                    "with Center=Mean and Spread=Std. Dev.");
        pm.print(y1);
        pm.setTitle("Filtered X2 Using Bounded Z-score Scaling\n"+
                    "with Center=Median and Spread=MAD/0.6745");
        pm.print(y2);
        
        // Perform inverse filtering
        double[] z0, z1, z2;
        z0 = scaleFilter[0].decode(y0);
        z1 = scaleFilter[1].decode(y1);
        z2 = scaleFilter[2].decode(y2);
        pm.setTitle("Decoded Z0");
        pm.print(z0);
        pm.setTitle("Decoded Z1");
        pm.print(z1);
        pm.setTitle("Decoded Z2");
        pm.print(z2);

    }
}
